package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(`*``!````49L``#0```"XL@```@``!30`(``)
M`"@`&P`:``$``'!XH```>"`!`'@@`0`(````"`````0````$````!@```#0`
M```T@```-(```"`!```@`0``!0````0````#````5`$``%2!``!4@0``$P``
M`!,````$`````0````$``````````(````"```"`H```@*````4`````@```
M`0```/2N``#TK@$`]*X!`'@"``"P$@``!@````"````"`````*\```"O`0``
MKP$```$````!```&````!`````0```!H`0``:($``&B!``!$````1`````0`
M```$````4>5T9```````````````````````````!@````0```!2Y71D]*X`
M`/2N`0#TK@$`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!`````!````1TY5```````"````!@```!`````$````%`````,```!'
M3E4`D>\>&?O1;D4]RHM7Q6VNC3M5_,MA`````P```"`````*````H!(`"`)&
M$:#`````5@!Q&,((`#P-`!41```0`@`H`````````%@B(`H$"@!$A`>H0`A%
M8&D`A`D^0CR7``$`""%0@"0)8`R!>$E`6@!``$```0!"&P%`@(S`A``"$)`0
M@PD`"`$0D(E`0,))@"Q`F`!``"``(`0)@)0!Y(Z7=D@#``````````0````%
M````!P`````````````````````````(````"@````P````.``````````\`
M```1````%0`````````7```````````````8````&P```!P````@````(0``
M`"(````D`````````"4````F````*@`````````L````+0```"X````O````
M,``````````R`````````#8````W`````````#L``````````````#P````^
M````/P````````!`````00```$,```!%````2`````````!+````3````$T`
M``!.````````````````````40````````````````````````!3````5```
M``````!6`````````%@```!:````7````%T```!>``````````````!?````
M8P````````!E`````````&<`````````:0```&L`````````;0```&X```!O
M````<0```'(```!V````7Y:3'*-:[Y!6VY,<PXZ'_PTZEPO2402$@72"#7KP
M2FM]08[%=E0\E,T_#*_W(\X@U&34?"%TL`+@4G<H+DX]]F:OS&;;]P!>!J2'
M_P&O-.BQ2)WGX*<""LY*KO_/WD<MXT?&`6QSA<7L/Y`"Q@[@/3]^EGPU;T[>
MQ8D%D&"8[Q)G24DB`2/YI)V[DQQ\[1$/H))H9X;YG(%#1=7LNI63'%N:.P]!
M39U\<80PA"U5Z]:GW:-K6.^7>:,`9:\,%.*>H@+V&=K-XYX%,J6%^Z%L8#)B
MV^WJT^\.R#E`'[F-\0[I^\/"2B)]_^W>DQRM2^/`V7%8'"O0X2(L#K%S&Y_6
MO5@[0!_#Y3\LF"+4:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$8C?C\,%#\N_(
MYN]?>]Z%($^;Z'P8WNLB%4]::,G%N9Q`,+B"#5$;?5^R`8MOO]I7&W9OXW"]
MT$M]:@E#UI\BQZ@A8F0'4ZD'D!T"$%%^J9R;8M#Z@NPL]HMK?YI\T)\L_(?P
MEGSN"U'Y\]O3'9!U@@U#9DL07E]V8`5LLLT6ZEKQ/:TY#2G\#:BCX/M)XE?$
M&%>26E+]TN\/+-_^2&[%WQ^@(@L@?9`0Z2[%F[;(U;)QWJO*GT>8!<8`````
M````````````````$0``````````````(````"```````````````"`````J
M!```$)L````````2````]`(``+29````````$@```(L#``!@F0```````!(`
M``!O`P``/)H````````2````4P4``%BQ`0``````(``6`'H"``"<EP``````
M`!(```!H`P``^)H````````2````:@(``-B8````````$@```(H%``"IO@``
M-````!(`#0"`!```;+$!```````0`/'_(@,``)R:````````$@```$T#```4
MF0```````!(```#5!```<;L``.("```2``T`P`,``)R9````````$@```+$`
M``!@EP```````!(````Q!```J)<````````2````#P4``*6O``#`````$@`-
M`#,#``"$F0```````!(```#8`P``;)@````````2````CP0``*3!`0``````
M$`#Q_U`!``!@F@```````!(```#Y!```>:T``)(````2``T`+04``#"9````
M````$@```+H%``#)L@``I@@``!(`#0"X!```C:\``!8````2``T`K0,``&R:
M````````$@```$,"``"LF@```````!(```!:`P``N)H````````2````'0,`
M`!R;````````$@```(`!``#HEP```````!(```!$!```<+$!``0````A`!<`
MW`(``$B9````````$@```,H#``"0F0```````!(```#C`@``*)L````````2
M````?0,```B9````````$@```&(#``"$EP```````!(```"-`0``T)<`````
M```2````H````.28````````$@```&T$``!LL0$``````!``\?_\`P``])<`
M```````2````U@(``&R9````````$@```/P"``"0F````````!(````=`0``
M>)H````````2````_@$``#":````````$@```$4$``!PL0$`!````"$`%P":
M!```I,$!```````0`/'_[````/"9````````$@```,4$```1P0```@```!(`
M#0`<`@``&)@````````2````9@4``-'```!`````$@`-`$X"``!XF0``````
M`!(```#'!0``);(``*0````2``T`5P4``%&;````````$@`-`,\$```5P0``
M`````!(`#@`\`P``S)D````````2````8`4``$&7````````$@`+`-<````D
MF@```````!(```"?`P``2)@````````2````=@,``-B9````````$@```$(%
M```<P0``!````!$`#P!T!```;+$!```````0`/'_`P0``(2:````````$@``
M`#0```#,F````````!(````;!```")H````````2````70$``/"8````````
M$@```%X%```!K0``+@```!(`#0"A`0``>)<````````2````H@0``*3!`0``
M````$`#Q_]D%```1K@``>@$``!(`#0#]````#)@````````2````"P,``!B:
M````````$@```'@````XFP```````!(```#"`@``G)@````````2````7`(`
M`%29````````$@````L!``!$FP```````!(```![!0``A,0``.I;```1``\`
M00$``#R9````````$@```&,```#LF@```````!(```#J`0``8)@````````2
M````0@```/R9````````$@```$,$``!PL0$`!````!$`%P"$`P``))@`````
M```2````R@$``#"8````````$@```.L$``#EL0``,````!(`#0".!```I,$!
M```````0`/'_N`,``)"7````````$@```,@```#\F````````!(```!1!0``
M6+$!```````0`!8`#00``)":````````$@```%L$``!XL0$`!````!$`%P!N
M`0``W)<````````2````CP````2;````````$@```!L%```5L@``$````!(`
M#0"8`@``5)@````````2````A0(``$B:````````$@```#X$``#=O@``Y`$`
M`!(`#0#H`P``/)@````````2````I@$``(28````````$@```-\#``!4F@``
M`````!(```"C`@``?+$!`!,````1`!<`F`,``"29````````$@```)(#``#D
MF0```````!(````O`0``M)@````````2````*@,``.":````````$@```",$
M``"HF````````!(```"1`@``P)D````````2````V`$``-":````````$@``
M`.8%``!EL```@`$``!(`#0#O`P``P)@````````2````JP$``*B9````````
M$@```%0#``!LEP```````!(````L`@```)@````````2````-@4``%6^``!2
M````$@`-`*8%``!HL0$`!````!$`%@!4````Q)H````````2````IP0```VN
M```"````$@`-`+<!``"TEP```````!(````U`@``>)@````````2````=@4`
M`&2Q`0`$````$0`6``!L:6)P97)L+G-O+C4N,3``7U]G;6]N7W-T87)T7U\`
M7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?27-T871B
M=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA9W-?<'1R`%!E
M<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T<@!097)L7V%T
M9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R7W!T<@!097)L
M7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O<%]E;G9?<'1R
M`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?;F5W4U9P
M=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R`%!E<FQ?26]P
M7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!097)L7VUG7W-E
M=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7T=T:')?
M:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E<FQ?9&5S=')U
M8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O
M=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T
M:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`
M97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A
M:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I9`!S
M=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M8W!Y`%]?<W1R
M;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E
M7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T
M<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+G-O
M+C,`7U]S=&%C:U]C:&M?9W5A<F0`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S
M7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`'!A<E]C=7)R96YT
M7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-L96%N=7``7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`'AS7VEN:70`
M7U]L:6)C7V-S=5]I;FET`&YA;65?;&]A9%]M>5]P87)?<&P`6%-?26YT97)N
M86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M>5]P87)?<&P`<&%R7VUK
M=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXT```````````"``,``@`"``$````"`````0`!``(`
M`@`!``(````"``$``@`"``$````!``(``0`!``(````"``(````"``,``@`#
M``(``@```````0`"``,``P```````@`!`````0````$````!``$``0`"``$`
M```"``(``0`!``(````"`````0````$``0````(````#```````!````````
M`````@`"`````0`!``(````!``(`!````````0```````0`"``(``@````(`
M`@````(``@`"`````0`"`````@````$``0````$```````$````!``$`300`
M`!`````@````%&EI#0``!`#S!0````````$``0"R`@``$````"`````4:6D-
M```#`/,%`````````0`!``$#```0`````````!1I:0T```(`\P4```````!4
ML0$`%0$``'"Q`0`44P``>+$!`!1<``!\L0$`%&8```RP`0`6$0``$+`!`!9Q
M```4L`$`%D4``!BP`0`6)@``'+`!`!98```@L`$`%@@``"2P`0`6$@``*+`!
M`!9W```LL`$`%@$``#"P`0`6)P``-+`!`!9=```XL`$`%B```#RP`0`6*@``
M0+`!`!9R``!$L`$`%D@``$BP`0`6,P``3+`!`!94``!0L`$`%E4``%2P`0`6
M8P``6+`!`!8\``!<L`$`%F```&"P`0`640``9+`!`!85``!HL`$`%G@``&RP
M`0`69```<+`!`!8L``!TL`$`%DL``'BP`0`6:P``?+`!`!9I``"`L`$`%F\`
M`(2P`0`600``B+`!`!8*``",L`$`%B@``)"P`0`60P``E+`!`!99``"8L`$`
M%B4``)RP`0`6#@``H+`!`!9G``"DL`$`%AD``*BP`0`63P``K+`!`!8B``"P
ML`$`%DP``+2P`0`6!0``N+`!`!8K``"\L`$`%C4``,"P`0`6%```Q+`!`!8C
M``#(L`$`%A```,RP`0`6<```T+`!`!8$``#4L`$`%FP``-BP`0`6.0``W+`!
M`!8]``#@L`$`%F@``.2P`0`6,0``Z+`!`!92``#LL`$`%D(``/"P`0`620``
M]+`!`!8[``#XL`$`%BX``/RP`0`6!@```+$!`!9A```$L0$`%F4```BQ`0`6
M%P``#+$!`!8<```0L0$`%BT``!2Q`0`60```&+$!`!9;```<L0$`%@T``""Q
M`0`6'0``)+$!`!8>```HL0$`%G4``"RQ`0`6;0``,+$!`!9J```TL0$`%E``
M`#BQ`0`6"0``/+$!`!9>``!`L0$`%@,``$2Q`0`6'P``2+$!`!8D``!,L0$`
M%DH``%"Q`0`630``"+4`\"'Z`+\(O0``!.`MY03@G^4.X(_@"/"^Y:08`0``
MQH_B$<J,XJ3XO.4`QH_B$<J,XISXO.4`QH_B$<J,XI3XO.4`QH_B$<J,XHSX
MO.4`QH_B$<J,XH3XO.4`QH_B$<J,XGSXO.4`QH_B$<J,XG3XO.4`QH_B$<J,
MXFSXO.5X1\!&`,:/XA'*C.)@^+SE`,:/XA'*C.)8^+SE`,:/XA'*C.)0^+SE
M`,:/XA'*C.)(^+SE`,:/XA'*C.)`^+SE`,:/XA'*C.(X^+SE`,:/XA'*C.(P
M^+SE`,:/XA'*C.(H^+SE`,:/XA'*C.(@^+SE`,:/XA'*C.(8^+SE`,:/XA'*
MC.(0^+SE`,:/XA'*C.((^+SE`,:/XA'*C.(`^+SE`,:/XA'*C.+X][SE`,:/
MXA'*C.+P][SE`,:/XA'*C.+H][SE`,:/XA'*C.+@][SE`,:/XA'*C.+8][SE
M`,:/XA'*C.+0][SE`,:/XA'*C.+(][SE`,:/XA'*C.+`][SE`,:/XA'*C.*X
M][SE`,:/XA'*C.*P][SE`,:/XA'*C.*H][SE`,:/XA'*C.*@][SE`,:/XA'*
MC.*8][SE`,:/XA'*C.*0][SE`,:/XA'*C.*(][SE`,:/XA'*C.*`][SE>$?`
M1@#&C^(1RHSB=/>\Y0#&C^(1RHSB;/>\Y0#&C^(1RHSB9/>\Y0#&C^(1RHSB
M7/>\Y0#&C^(1RHSB5/>\Y0#&C^(1RHSB3/>\Y0#&C^(1RHSB1/>\Y0#&C^(1
MRHSB//>\Y0#&C^(1RHSB-/>\Y0#&C^(1RHSB+/>\Y0#&C^(1RHSB)/>\Y0#&
MC^(1RHSB'/>\Y0#&C^(1RHSB%/>\Y0#&C^(1RHSB#/>\Y0#&C^(1RHSB!/>\
MY0#&C^(1RHSB_/:\Y0#&C^(1RHSB]/:\Y0#&C^(1RHSB[/:\Y0#&C^(1RHSB
MY/:\Y0#&C^(1RHSBW/:\Y7A'P$8`QH_B$<J,XM#VO.4`QH_B$<J,XLCVO.4`
MQH_B$<J,XL#VO.4`QH_B$<J,XKCVO.4`QH_B$<J,XK#VO.4`QH_B$<J,XJCV
MO.4`QH_B$<J,XJ#VO.4`QH_B$<J,XICVO.4`QH_B$<J,XI#VO.4`QH_B$<J,
MXHCVO.4`QH_B$<J,XH#VO.4`QH_B$<J,XGCVO.5X1\!&`,:/XA'*C.)L]KSE
M`,:/XA'*C.)D]KSE`,:/XA'*C.)<]KSE`,:/XA'*C.)4]KSE>$?`1@#&C^(1
MRHSB2/:\Y0#&C^(1RHSB0/:\Y0#&C^(1RHSB./:\Y0#&C^(1RHSB,/:\Y0#&
MC^(1RHSB*/:\Y0#&C^(1RHSB(/:\Y0#&C^(1RHSB&/:\Y7A'P$8`QH_B$<J,
MX@SVO.4`QH_B$<J,X@3VO.5/\``+3_``#EWX!!MJ1DWX!"U-^`0-W_@4P$WX
M!,T$2`1+__<:[O_W!NX``!'!``#=O@``T<````-+!$I[1)M8"['_]Q6^<$=P
M%`$`5`$``$ORCQ/`\@$#&G@*N0$B&G!P1P"_2O;\8,#R`0`(M0-H*[%`\@`#
MP/(``P.QF$<(O2WI\`_4L`#Q'`$#J@2K$ZU1^`1+)+I"^`1/JD+XT0`B'FH$
MKUEKG6B\6(;J`0%I0`0R84!/ZO%Q&60$,[+U@'_NT4%H1_:9%`9IQ?:")`2:
M1_:9$T_JL04!:+(8!9\4&49H!.OQ:<1H3^JQ#`7J`0(DZ@8(YQF$:,7V@B/=
M^!B@^Q@DZ@$&06A&Z@("!YX$Z@$'!.L*`4CJ!P=']ID43T2;&,7V@B1']ID2
M-!G%]H(B`^OW8]WX(("*&&09)>H'`4?VF15/ZK<)Q?:")0?J#`<LZ@,&140"
MZ_-B.4-/ZK,'`^H)`U$8W?@DH$;J`P.L1$?VF1@*G4?VF1OD&,7V@BC%]H(K
M!.OQ9-!$JT0GZ@0*3^JQ!<A$"YHIZ@$)NT1']ID3`>H'!T_JM`9)Z@<'#.OT
M;,7V@B,L0+Q$2NH$`=,8#)Q']ID2#9]!1,7V@B)']ID:`>O\8:(8Q?:"*D_J
MO`DEZ@P$DAFZ1`.2#I\,Z@8"6QE']ID53^JQ#";J`08+Z_%K1.H"`@'J"0'%
M]H(E6D1&Z@$!?1DIZ@((`NH,!V5$6Q@!E4?VF10/G4CJ!PC%]H(D3^JR!P/K
M\F(LZ@(,`NH'`RP9`YU,Z@,#RD00F9I$1_:9&P7K\F.81$_JL@+%]H(K".H"
M`Q&>Y!F+1"?J"`=']ID1W?A(D!]#Q?:"(4?VF1-Q&,7V@B-/ZK@&"NOX:)-$
M2T0BZ@@"".H&"=WX3,!"Z@D"1_:9&<7V@BFD&.%$W?@$P(D9W?A0H`SK^&5/
MZK@([QE#1`?J"`(FZ@<&!.OW9$_JMP4$Z@4'*.H$"-WX5,!(Z@<(1_:9%POK
M]&L60\7V@B=>1&=$1_:9$D_JM`P&Z@P$J41!1"7J!@7%]H(B`>OV847J!`A2
M1$_JM@5B1`'J!08LZ@$,`Y-,Z@8,%IOA1$?VF13=^`S`Q?:")'\9'!D,Z_%C
MF$1/ZK$!".H!`R7J"`5%Z@,,3^JX!0GK^&AD&`CJ!0DAZ@@!`NOX8MWX7*"4
M1-WX8+!!Z@D)1_:9%D[VH3-/1,7V@B;&]MEC!^O\9UM$3^JX"%9$3O:A,=WX
M9*`#ZP@)3^J\`@SJ"`-V&<;VV6$EZ@P%'4,HZ@<(!^H"#%%$!.OW9$_JMP=D
M&=WX:+!(Z@P,B1A.]J$SA^H"`F9$8D#&]MECD41;1$_JM`(&Z_1DW?ALH`/K
M!PQ.]J$X@NH'!T_JM`;=^'"P9T#&]MEH">OT9$[VH3/01,;VV6-/ZK0)6T20
M1,D9ANH"`MWX=*!B0)L9`>OT88GJ!@9.]J$UE$1.0,;VV65/ZK$$W?AXL+!$
M#.OQ855$3O:A-MWX?*`#DTU$()N$Z@D)3O:A,L;VV6:)Z@$,GAE/ZK$)`YO&
M]MEB".OQ85)$B>H$"HKJ`0J<1$[VH3<,Z_%L543&]MEG3^JQ"DI$7T2*Z@D)
M3^J\"`7K_&4_&=WXA+")Z@P)3O:A,U9$N42(Z@H*QO;98T_JM0<)Z_5IBNH%
M#%M$0T241(?J"`@,Z_EL3^JY!8CJ"0@BG(7J!PE&1$[VH3$&Z_QHQO;984_J
MO`:)Z@P,(YJ&Z@4)81AC1$[VH3Q/ZK@$`^OX8\D9B>H(",;VV6R$Z@8)))^(
M1)1$3O:A,D_JLP$(Z_-HK$2)Z@,#QO;98H'J!`DEG9Q$NAA.]J$S#.OX;$_J
MN`>2&8GJ"`C&]MECA^H!"2:>D$3K&$[VH3)/ZKP%".O\:!L9QO;98HGJ#`2%
MZ@<*W?B<D!P9LAA.]J$S3^JX!@3K^&12&(KJ"`S&]MECW?B@H)1$2T1.]J$R
MANH%"0SK]&Q/ZK0!VQF)Z@0$QO;98H'J!@DIGP/K!`A21$[VH3,(Z_QH3^J\
M"E(9B>H,!,;VV6,JG8KJ`0P4&?L83O:A,@3K^&1/ZK@'C.H(#)L9QO;98JH8
M8T2'Z@H%`^OT;%$8*YME0$[VH3)/ZK0$31G&]MEB3^J\`07K_&::&"R=A.H'
M"$OVW$.(Z@P(0>H$"9)$R/8;<T_JM@+=^+3`PD3K&`'J!`@)Z@8)2_;<10KK
M]F;;&4GJ"`E"Z@$'R/8;=0?J!@B91&5$`NH!!T_JM@/=^+C`">OV9BP92.H'
M!TOVW$5#Z@(*YQG(]AMU3^JV!`?K]F?=^+R`940*Z@8*`^H"#$OVW$9M&$3J
M`PE*Z@P*R/8;=D_JMP'=^,#`JD1&1`GJ!PD$Z@,(2_;<10KK]V>R&,CV&W5)
MZ@@&0>H$"0'J!`AE1)89">H'"4_JMP(&Z_=FW?C$P.L82>H(!TOVW$5"Z@$*
MWQG(]AMU3^JV`P?K]F?=^,B`940*Z@8*`NH!#$OVW$8M&4/J`@E*Z@P*R/8;
M=D_JMP3=^,S`JD1&1`GJ!PD#Z@((2_;<10KK]V=Q&,CV&W5)Z@@&1.H#"03J
M`PAE1(X9">H'"4_JMP$&Z_=FW?C0P*H82>H(!TOVW$5!Z@0*UQG(]AMU3^JV
M`@?K]F?=^-2`940*Z@8*`>H$#$OVW$;M&$+J`0E*Z@P*R/8;=D_JMP/=^-C`
MJD1&1`GJ!PD"Z@$(2_;<10KK]V<T&<CV&W5)Z@@&0^H""0/J`@AE1*89">H'
M"4_JMP0&Z_=FW?C<P&D82>H(!TOVW$5$Z@,*SQG(]AMU3^JV`0?K]F?=^."`
M940*Z@8*!.H##$OVW$:M&$'J!`E*Z@P*R/8;=D_JMP+=^.3`JD1&1`GJ!PD!
MZ@0(2_;<10KK]V?S&,CV&W5)Z@@&0NH!"0+J`0AE1)X9">H'"4_JMP,&Z_=F
MW?CHP"P92>H(!TOVW$5#Z@(*YQG(]AMU3^JV!`?K]F?=^.R`940*Z@8*`^H"
M#$OVW$9M&$3J`PE*Z@P*R/8;=D_JMP'=^/#`JD1&1`GJ!PD$Z@,(2_;<10KK
M]V>R&,CV&W5)Z@@&0>H$"0'J!`AE1)89">H'"4_JMP(&Z_=FW?CTP.L82>H(
M!TOVW$5"Z@$*WQG(]AMU3^JV`P?K]F?=^/B`940*Z@8*`NH!#$OVW$8L&4/J
M`@E*Z@P*R/8;=D_JMP7=^/S`HD1&1`GJ!PD#Z@((2_;<1`KK]V=Q&,CV&W1)
MZ@@&1>H#"-WX`*%D1`CJ!P@%Z@,,CAE,\M81!NOW9J(83^JW!TCJ#`3,]F(A
MW?@$D5%$%!F'Z@4*3/+6$D_JM@P$Z_9DRQB*Z@8&S/9B(D*9`^L&"$I$3/+6
M$XSJ!PD(Z_1H3^JT!E(9B>H$!,SV8B.&Z@P)0YT4&<L83/+6$@3K^&';&4_J
MN`2)Z@@'S/9B(H3J!@C=^!"AWQFJ&$SRUA,'Z_%E8D1/ZK$'S/9B(XCJ`0'=
M^!21`NL!#%-$3/+6$H?J!`I/ZK4!#.OU;)L9BNH%!<SV8B)&G@/K!0A*1$SR
MUA.!Z@<)".O\:$_JO`42&8GJ#`S,]F(CA>H!"4><E$3S&$SRUA)/ZK@&#.OX
M;-L9S/9B(HGJ"`?=^""AANH%"=\9HAA,\M833^J\!`?K_&=2&(GJ#`S,]F(C
MW?@DD0+K#`A31$SRUA*$Z@8*".OW:$_JMP%;&8KJ!P?,]F(B2IT#ZP<,2D1,
M\M83@>H$"4_JN`<,Z_ALDAG,]F(CB>H(!MWX+*&'Z@$)EAGK&$SRUA)/ZKP%
M!NO\9AL9B>H,#,SV8B+=^#"1`^L,"%)$A>H'#$SRUA,(Z_9H3^JV!%(8C.H&
M!LSV8B--F9892T1,\M82A.H%"4_JN`P&Z_AFVQG,]F(BB>H(!XSJ!`K=^#B1
MWQF*&$SRUA-/ZK8!!^OV9U(9BNH&!LSV8B-/G0+K!@A+1$SRUA*!Z@P)".OW
M:$_JMP8;&8GJ!P?,]F(BANH!"5"<WQFJ&$SRUA,'Z_AE8D1/ZK@'B>H(#,SV
M8B.'Z@8(E$3C&`SK]6Q/ZK4$6QB(Z@4%W?A$H=WX2)%=&4SRUA),\M83S/9B
M(LSV8B-21$M$A.H'"D_JO`$%Z_QEDAG=^$R!BNH,!ML9!VB!Z@0)EAE,\M82
M!NOU9D_JM0RX1(GJ!07,]F(B6QE"1(SJ`042&75``^OV8T1H4AF%:!\9`NOS
M8P7KM@;$:`-@!6D,ZP0"1V!)&89@PF`!852PO>CP#W!'`+\MZ?A#!4:)1@BY
MO>CX@TOR<!/`\@$#T_@`@+CQ``\"T4!&O>CX@P-X'QX8OP$G/2L,OP`G!_`!
M!W>Q0QP?1A/X`2L1'AB_`2$]*@R_`"(!\`$"`"KRT7\;V/@`0,RQ1D8@1BE&
M.D;_]T+I$+GC73TK!M!6^`1/`"SRT2!&O>CX@\CK!@9X'"`8MA#)^`!@O>CX
M@R!&O>CX@P"U@[`!J?_WK_\#L`"]`+\PM05&@[!+\G`4*$8!J<#R`03_]Z'_
M<+$!FB-H`^N"`UIH0_@$*P`J^M$H1@&I__>3_P`H\-$#L#"]`+\0M0`@__<:
MZ0!H_O?^[_[W7N\#:``@7&C_]Q#I`&C^]_3O_O>2[P-&`"`;>"-V__<&Z0!H
M_O?H[_[W2.\#:``@7&C_]_SH`&C^]][O_O>"[P-H`"`;BL/S"`-C@__W[N@`
M:/[WTN_^]S+O`V@`(%QH__?DZ`!H_O?([TSR*#$`(L#R``'_]Z+HX&$`(/_W
MUN@`:/[WNN_^]QKO`V@`(%QH__?,Z`!H_O>P[_[W2.\#:``@(V+_]\+H`&C^
M]Z;O_O<&[P-H`"!<:/_WN.@`:/[WG.__]T3H`VA+L0`@__>NZ`!H_O>2[__W
M.N@#:-MN8V(`(/_WI.@`)`!H_O>&[_[WYNX#:"!&6VB<8O_WF.@`:/[W>N_^
M]]KN`V@@1EMHW&+_]XSH`&C^]W#O_O?0[@-H($9<:/_W@N@`:/[W9N__]U+H
M`V@C8Q"]\+4$1IVP"+$#>`NY';#PO?[WT.X%1@`H^-`H1O_W1.@#1@#Q$P8@
M1@`K-=#:?"XJ.=#^]WSO!T8P1O[W>.\X&`(P_O?0[TSRD!,!(<#R``-/\/\R
M`)0!E@=&__<LZ`,@.48"JO[WK.^P\?\_.$8%T`:;`_1P0[/U@$\=T/[W7.\X
M1O[W$N\H1O_W#N@#1@#Q$P8@1@`KR=$H1O[WAN\@1O[WLN^RYQI]`"JVT"XJ
MP-%;?0`KL="\Y__WHO_@YP"_.+4$1@`@__<6Z`!H_O?X[O[WIN\A1@)&`R#^
M]]KO!48(L0`@.+W_]P;H`&C^]^CN_O>6[P-I`_1P0[/U@$\/T"A&_O?X[P!H
M_O?:[O[WB.\#:0/T<$.S]2!/`=`H1CB]`B$@1O[WTN[0\0$`.+\`(#B]`+\M
MZ?!'#$8+>(2P!D8]*PB_3!P@1O[W\.X#J0=&,$;_]S_^!49HL?[WZ.Z'0@#R
MBH`4^`$+!?@!"P`H^=$$L+WH\(=+\G`8P/(!"-CX`*#:^``P`"M^T%-&4_@$
M+P$U`"KZT:D<B0!+\I`3P/(!`QIH2K%01O[WF.\#1LCX``"@N4_P_S#:YP$B
M"$8:8/[W$.\`*/703^J%"5%&2D8!D/[W+.\!F\CX`#`!X$_JA0EJ'``A0_@B
M$`.5,W@P1AH>&+\!(CTK#+\`(P+P`0-KL7,<&$83^`$K$1X8OP$A/2H,OP`B
M`?`!`@`J\M&`&P(W.!C8^`"`_O?<[DOR<!7`\@$%2/@)```HN]`J:`.9,WA2
M^"$0"W!CL3TK"M!*'`'@/2L&T!;X`3\11@+X`3L`*_;1"T8](@IP%/@!"P/X
M`0\`*/G1>^<#FTOR<!C`\@$(3^J#";'G""$=1H7G`+_PM4OR>!2M]8!=P/(!
M!(.P!D8C:`WU@%4$-4SRF!`/1L#R```K8`&I0/;_<O[WW.X%'B+=`:I3&1/X
M`3S;L0&H+R$J1O[W(N^XL0`@_O<*[P!H_O?N[3%&`:HK1O[W..X-]8!3!#,:
M:"-HFD(0T0.P#?6`7?"]`3WAT0`@_O?R[@!H_O?6[3%&.D;^]YSMY^?^]V;N
M$+4`(/[WY.X`:/[WR.U,\J@12?;8`DSRQ!/`\@`!P/(``L#R``.]Z!!`_O>]
MO@"_$+4`((*P3/(H-/[WRN[`\@`$`&C^]ZKM__?:_P`@_O?`[@!H_O>B[4SR
MT!%+]G$R(T;`\@`!P/(``@"4`"0!E/[WONT"L!"]<+5+\G@4K?4`7<#R`02&
ML$SR]!4C:`WU`%(4,L#R``438/[W4.Y,\N@3`2%!\@$"P/(``P&5`)`-]8!0
M$##^]VSN`"@,V@`E#?4`4RA&%#,::"-HFD(:T0:P#?4`77"]#?6`4$_T@%(0
M,`.I_O<V[@8>Z-MP'/[WZ.T%1@`HX]`#J3)&_O>2[0`CJU7<Y_[WXNT`O[3G
M`+\MZ?!'2_)X&*WU@%W`\@$(AK`&1MCX`#`-]8!2%#),\OP0P/(```Q&$V#_
M]P7]+R$%1C!&_O?6[*BQ3/(((#%&P/(``/_W7/X-]8!3,$84,QIHV/@`,)I"
M0/"-@`:P#?6`7;WH\(<P1O[W1NU,\A@AP/(``8)&($;^]Z;M!$8`*-O03/+X
M&06OP/(`"2-X`"L(OTQ&+;$H1B%&_O<R[@`H3=`@1O[W*.TC&!/X`2PO*@?1
M`"$#^`$=`3@3^`$L+RKXT`KQ`0,8&+#U@%^UVDSR'",!(4_T@%+`\@`#3/(D
M+CA&P/(`#@"4S?@$X`*6_O?([0`@_O?D[0!H_O?([/[W=NTY1@)&`R#^]T#M
M8+G^]]CM`&C^][KL_O=H[0-I`_1P0[/U`$\4T$SR&"$`(,#R``'^]TKM!$8`
M+*?1?>=,\A@AP/(``?[W0.T$1@`LG=%SYSA&`2'^]Z#L`"CDT4SR""`Y1L#R
M``#_]\K].$;^][#M!D9HY_[W(NT`OP-X.[%"'"\K"+\01A+X`3L`*_C1<$<`
MOQ"U!$8`*"'0`W@`*Q[0_O>J[`$X(AB40@O2(UPO*S/14QX#X!/X`1DO*2W1
MG$(:1OC3HD(8T1-X+RLOT$SR)"#`\@``O>@00/[W=KT"(/[WYNP#1K"Q3/+X
M$0(BP/(``;WH$$#^]XJ\4QZ<0AI&`](3^`$9+RGXT!(;DQRS]8!?$]D`(QA&
M$+U3'@/@$_@!&2\ISM"<0AI&^-/*YP(@_O>^[`-&`"C6T>SG3_2`4P-((48!
M,O[W]NL`2^/GE+$!`/"U3/(@%L#R``:+L&U&2_)X%`_.P/(!!"=H#\4/S@F7
M-H@/Q4SR*"#`\@``+H#_]^'[3/(T(,#R``#_]]O[3/(\(,#R``#_]]7[3/)(
M(,#R``#_]\_[3/)0(,#R``#_]\G[3/)@(,#R``#_]\/[3/+\$,#R``#_][W[
M3/)L(,#R``#_][?[3/)X(,#R``#_]['[3/*$(,#R``#_]ZO[3/(((,#R``#_
M]Z7[3/*0(,#R``#_]Y_[3/*<(,#R``#_]YG[3/*H(,#R``#_]XO[`48HL4SR
M>"#`\@``__?G_$SRO"#`\@``__=]^P%&*+%,\M`@P/(``/_WV?Q,\MP@P/(`
M`/_W;_L!1JBQ3/+\$,#R``#_]\O\3/)0($SR##'`\@``P/(``?_WP?P)FB-H
MFD(DT0NP\+U,\NP@P/(``/_W4?L!1C"Q3/)L(,#R``#_]ZW\X.=,\@`Q#?$1
M`,#R``$*(O[W:NP`*-713/)L(`WQ&P'`\@``__>9_,SG_O?TZQ"U2_)@%,#R
M`00@:+#Q_S\`T!"]3/)L(,#R``#_]R+[(+$`>!"Q,#@8OP$@(&`0O0BU_O<J
MZ_[WBNL`L0!H"+TMZ?!#!T8F3(NP!*TN1@_,#\:4Z`,`!)R&Z`,`(WCKL4SR
M&"C`\@`(!N#^]XCKP+%5^`1/(WB+L2!&__?S^CE&!D80L0-X`"OOT2!&.4;_
M]TW\5?@$3R-X`"OMT0NPO>CP@SA&_O<^ZX%&,$;^]SKK2$0",/[WDNM,\APC
M`2%/\/\RP/(``P"7S?@$@`*6@4;^]^SK($9)1O_W*/S(YP"_1,$``"WI\$^!
M1I5,K?4`3<VP2_)X&P3Q$`<<KI3H#P#`\@$+#?4`2!:MV_@`P`CUEG@$\2@.
M(*R&Z`\`#\_(^`#`K$:LZ`\`E^@#`(SH`P">Z`<`A.@'`$SR_!#`\@``__>0
M^@=&&+$#>``K0/!M@__W;O^`1@`H`/!Q@YCX`$!TL?[W).M#1E\A`F@R^!0@
M$O`(#PB_&7`3^`%/`"STT1:8`W@`*P#P&8,!)P;@5?@G``$W`W@`*P#P$(/_
M]V+Z!$8`*//0__>'^P`H[]`@1O[WI.L`*.K0!$8@1DSR)";^][#JP/(`!@=&
M0$;^]ZKJ/Q@']8!G!#<X1O[W`.L%1CA&"97^]_KJ3/(8,P$A3_#_,L#R``-,
M\B0^`)3`\@`.`9;-^`C@S?@,@`=&_O=.ZSA&0/+M$?[WN.E,\FA`P/(``/_W
M'_H`*`#P!H/9^`!`_O=DZP%&($;_]_C\!$8`*`#P^H(@1O[W;NH#*(!&$]V@
M\00`3/(L,2`8P/(``?[W9NM(N;CQ!`\`\,&"H$08^`4\+RL`\+N"__?"_@%&
M`"A@T$SR;"!,\@PQP/(``<#R``#_]TO[3/(H./[WWNI,\E0S`2%/\/\RP/(`
M`\#R``@`EP`D`9;-^`R``I`H1O[W]NH6X/[W/NL#:!$K&M'^]\3J3/)D,P$A
M2D;`\@`#9!@`EP&6`Y3-^!"``I`H1O[WWNHH1D#R[1'^]T;IL/'_/X%&W]`X
M1O[WS.E,\OP0P/(``"E&__<*^RA&__>1_@WU`$P)F`SUEGS<^``@V_@`,)I"
M0/`H@TVP#?4`3;WH\(]<P0``($;^]P[J")``*)C03_#_,V_P$0(")`"4_O<X
MZ@B8(ZD&(O[WHNF=^(PP([F=^(TP0RL`\-&"#?4`2``B`",(\8P(")@`)`"4
M_O<@ZD+R`3X-]0!,QO)%?LCX`.`-]0!.#/&0#`[QE`Y*]HDP3?;^0<[VS7#)
M]KH!S/@``,[X`!`-]0!`#?4`09@PG#%%\G9"3O+P$\'R,@+,\M(S`F`+8`WU
M`$(-]0!##?4`2*`RI#,(\>@(JD:Y1A1@'&#(^`!`")@CJ4_T`$+^]T[I!!YS
MW0WU`$P,\:`,W/@`(`+KQ`.:0@#R^H$-]0!.#O&D#M[X`"`-]0!!#?4`2.@Q
M#?4`3`CQH`@,\:0,"&@"ZU1RR/@`,`WQC`C,^``@\+'`\4`(#?4`3D1%N+^@
M1@[QJ`YP1".I0D;^]V+I#?4`0.@P`VA#1`-@0"N[T0WU`$`CJ8PPR.L$!(A$
M_O>G^C\L&-TG1D5&#?4`0"E&0"*H,/[W1ND-]0!`C#!`/T`U_O>5^C\O[]Q`
M/*,)6AR;`9(!Y!J01`WU`$`B1D0CJ#!!1O[W_.@-]0!"Z#((F".I%&!/]`!"
M_O?:Z`0>B]P(F$]&_O="Z0WU`$.@,PWU`$P,]9A\#?4`2-/X`)"`(0CQI`A5
M1LGSQ0,,ZP,"`3,X*]CX`$`"^(@<`/.;@0WU`$(`(:@RT!C#\3@"_O=ZZ`WU
M`$A(\N,."/'@".Y$(@X-]0!!B/@`($CRY0B.^`!`(PPB"N(QZ$1(\N$,#?4`
M1.Q$Y#0*<`WU`$Y/ZAE"B/@`($CRYP*,^``P#O'F#D_J&6-J1"-P#?4`1)`T
M#?4`0$_J&2."^`"0CO@`,(PP#?4`3``A#/6,?`:1S?@<P`WU`$C^]PWZ(6@-
M]0!##?4`3`WU`$2,,PCQE`@,\9@,G#08:-CX`"`-]0!)U/@`H`P.W/@`,$_J
M$$@+E!0.#I1/ZA!N'`X1E$_J&F04E`WU`$3-^""`!/6,=$_J$4C-^#"`3^H2
M2(3X`.!(\AD4S?@\@$_J$TC-^$B`3^H:2,WX5(!L1-WX((!/ZA`LS?@HP$_J
M$2S-^#3`3^H2+(3X`(`-]0!$W?@H@`3UC73-^$#`3^H3+,WX3,`)\>P)A/@`
M@$CR&QCH1`WU`$0$]8YT3^H:+(CX```+F-WX,(`@<$CR'1!H1`V<@/@`@`WU
M`$A(\A\0"/6/>&A$B/@`0`WU`$0!<$CR(1`.F03UD'3=^#R`:$0A<`WU`$2`
M^`"`!/61=!"92/(C&!&8Z$0A<`WU`$$!]9)QB/@`($CR)102F@AP#?4`0-WX
M3(!(\B<1;$0`]9-P:42`^`"`2/(I&`MP#?4`0")P#?4`0Q6<2/(K$12:Z$0#
M]91S`/65<&E$B/@`0!IP@?@`H*I&@/@`P'5&W?@<@`:<`>`8^`%?3/),,PGK
M!``!(4_P_S+`\@`#`C0`E?[WF.@H+.[1#?4`2$SR/#,(]8IX3_``#DSR*#10
M1HCX`.`!(4_P_S+`\@`#P/(`!%5&`)<!ELWX")`#E/[W>NBCY1R=+'@`+#_T
M^JP!)P;@5O@G4`$W+'@`+#_T\:PH1O_W;?@`*//0*$;^]XKH`"CNT.3DV?@$
M@+CQ``\_]#^M0$;]]Y+O`RA_]CFM!#A,\C0Q0$3`\@`!_O>,Z``H"+]$1BSE
M#?4`0*0P`F@!,@7F__<)_#A&_O=DZ`F0<N79^`!``N4@F`-X@[$!)P3@5/@G
M``$W`WA+L?[W!_\`*/;0_O=0Z``H\M"`1GKD3/(0.,#R``B'Y`WU`$[#\4`"
M#O&H#@`A#NL#``WU`$C]]]SN#?4`0(PP"/&T"/[WJO@-]0!`#?4`0:@PK#$`
M(PWU`$(#8`M@#?4`3`WU`$X-]0!`#?4`0;`R#/&X#`[QO`[`,,0Q$V`-]0!"
MR/@`,`WU`$C,^``P#?4`3,[X`#`-]0!.`V`-]0!`"V`-]0!!R#((\<P(#/'0
M#`[QU`[8,-PQ$V#(^``PS/@`,,[X`#`#8`M@%^:=^(XP02M_]"JMG?B/,$,K
M?_0EK9WXD#!(*W_T(*V=^)$P12M_]!NM3_#_,V_P.0((F`"4_?<^[R.I*2((
MF$SR*#3]]Z;N3/(\,RA&`2%/\/\RP/(``\#R``0!E@"7(ZX#E`*6_?>4[[[D
M_?<P[P"_+>GP1P`@_?>L[P!H_?>.[OWWF.X!(P-P3/)0(,#R``#^]UK^&+$#
M>#$K`/#>@/_W8?H`($SRB";]]Y+OP/(!!@!H_?=T[DSR>#'`\@`!`2(+(_WW
M*NX`*$G03/*()L)HP/(!!E;X]#S2^!B``2M`\^R``"4!)`K@.$;]]Y+O`"@O
MT5;X]#P!-`$UHT(KW0`@_?=F[P!H_?=*[D%&*D8`(_WWH.Z"1N"Q`FA6^/`<
MDVA1^"1P$_2`:1B_T6C<T4A&_?=.[P!H_?<R[MKX`!!*1@(C_?>`[P%&.$;]
M]V+O`"C/T%;X]#Q:'JI"`/"#@``@_?<V[P!H_?<:[DSR@#'`\@`!`2(%(_WW
MT.T$1IBQ`"#]]R;O`&C]]PKNXVA,\H0RP/(``AEH_??,[>-H&VB;:!/T@`]Q
MT0`@_?<2[P!H_??V[4SRC#'`\@`!`2(%(_WWK.T$1IBQ3/(((,#R``#^][O]
M!48`*&/0`"#]]_KN`&C]]]SMXV@J1AEH_?>B[0`@3/*()0=&_??L[L#R`04`
M:/WWS.W]]];M`T8X1A]P_??@[@!H_??"[?WW].X#1DSR_!#`\@``'V#^]X[]
M1OCL#``H1-!`\NT1_?<8[0(>`T88OP$B$2@,OP`B`O`!`A*QL/'_/W+1O>CP
MAT-X`"L_]""O'.<!*W_W>J\!)``@`33]]Z[N`&C]]Y+M04;]]T;M5OCT/*-"
M\=QIYP`@_?>@[@!H_?>$[>-H&6C]]P;N@N?]]Y;N`&C]]WKMXFA6^/`\$&@9
M:/[W6O^9YP`E2^=5^/`,__>!^N-H&VB::$7X[`P2](!E&+_8:`O1*$;]]WCN
M`&C]]USMX6@J1@(C"6C]]ZKN5OCP'/WW(NWC:%;X\"P;:!9HGV@7](!G&+_:
M:`5&#-$X1OWW7.X`:/WW0.WA:#I&`B,):/WWCNX"1DSRD#`Q1L#R```K1OWW
M].U5^/`<3/+`,,#R``!5^.PL"6C]]^KM`+]PM05&__>D^`)X!$9BL01&`T8"
MX`$S&G@RL2\J^M$!,QQ&&G@`*OC1__>R^5BQ5;$K>$.Q3/(D,2!&P/(``?WW
M9NV$0@#0<+TH1KWH<$#^]YN]`+\0M0`@_?<0[@!H_??T[$_P_S']]][L`"#]
M]P;N`&C]]^KL2O:5`<#R``$`(KWH$$#]]RR^\+6'L`60!:@$D02I`Y(#JOWW
MZNU)\K1QP/(``4GVY``*1L#R````\-WX`"#]]ZKL!'BLN?WWH.Q,\H@CP/(!
M`T/XZ`P`*`#POX#]]^KL($;]]]#M`&C]][3L_?=\[01P`"#]]\CM`&C]]ZKL
M_??0[0-&`"`:>$+P`@(:</WWNNT`:/WWGNS]]\3M`WA#\`$#`W`%F`4P!^Z0
M"KCN9VN?[4U[-NX':Y_M37NT[L=K\>X0^G_<@`!,\H@D_?=8[029P/(!!`6=
M3/(40TSRA$+`\@`#P/(``@9&1/CP;`]H3/(00/-@!",!+;)@P/(``#=@<&`&
M\0P"1/CT/`?=`2-1^`0/`3.K0D+X!`_XT07Q`PY*]C%15/CH##-&`"=R1D;X
M+G#`\@`!`)?]]\KK3/*()<#R`04&1KBQ5/CH#$SRB"7]]ZSL3/)@(,#R``#`
M\@$%_O<,_.BQ5/CH#/WWH.O]]TCL,$8'L/"]5?CH#$SRB"7]]]CKP/(!!09&
M5/CH#/WWCNQ,\F`@P/(``/[W[_L`*.'15?CL#!"Q__?N_MOG3/+\$,#R``#^
M]^'[1?CL#``HT=#QYTSR2#!+\GP1P/(``,#R`0']]\#L`2#]]SKM`+^O\P"`
M`````````````(#____/00)+>T0#L1MH_?>DO);P```MZ?A#!D8,30]&W_@P
MD)!&?43]]RW[^43)ZP4%K1`)T``D6?@D,#!&.49"1@$TF$>L0O;3O>CX@Q3N
M```*[@``<$<`OPBU`+\(O0```0`"`%]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@`````$C$``!8Q```8,0``&C$``!PQ```*,,``#C$``!`Q```
M^,$``"C#``#0P@``U,(``"S$````P@``-,0``"C#```8Q```(,0``"C#```E
M<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(`<&5R;'AS:2YC````26YT97)N86QS.CI005(Z.D)/3U0`````+W!R
M;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````
M.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`
M````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`````4$%2
M7T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)
M4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`````%!!4E]#3$5!3CT``#$```!365-414T``"5S)7,E<R5S`````'!A
M<BT`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E,#)X````
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````$%21U8`````
M&````'!E<FP`````,````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@
M86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('1E
M;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET
M:"`E:2X*````+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`
M5$U0`$,Z7%1%35``+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,
M24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@````C(2]U<W(O8FEN
M+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO
M="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S
M=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R
M97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q
M>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N
M)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W
M:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T
M+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@
M>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H
M92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A
M;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK
M:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE
M<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@
M("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO
M;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@
M9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O
M8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI
M;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@
M("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@
M($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@
M("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+
M(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN
M+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G
M)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@
M*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@
M("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY
M("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G
M.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@
M("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@
M<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N
M86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@
M(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!
M4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@
M/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'
M0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*
M("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]]
M(&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@
M4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M
M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@
M8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S
M*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@
M(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@
M>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@
M(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX
M+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D
M8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@
M("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP
M86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@
M("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@
M(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY
M("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M
M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@
M;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ
M*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@
M(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`]
M(%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I
M('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D
M;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@
M("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@
M(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@
M(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT
M(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@
M("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P
M<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T
M>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D
M8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@
M("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@
M("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]
M?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M
M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI
M<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E]
M(&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@
M("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L
M92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U
M9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@
M<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE
M;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@
M("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT
M("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E
M("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L
M("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@
M("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D
M=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U
M;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE
M8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I
M<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H
M96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL
M93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@
M:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I
M;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@
M("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL
M97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI
M<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@
M("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]
M"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]
M?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C
M;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P
M("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@
M("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@
M("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I
M<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!0
M4D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@
M=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@
M=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO
M<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!
M4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*
M("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I
M('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I
M('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@
M("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@
M=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@
M/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@
M)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@
M("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@
M("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@
M("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?
M:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@
M("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T
M(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@
M*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I
M<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@
M("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`[
M"@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F
M:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2([
M"B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I
M92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N
M=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@
M;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H
M9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O
M<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@
M("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@
M97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@
M.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O
M=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W
M+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@
M/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@
M("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?
M1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@
M:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@
M/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N
M("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@
M?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@
M=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S
M('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ
M2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE
M<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE
M;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@
M("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@
M("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@
M0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I
M>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N
M=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET
M+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO
M(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D
M>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG
M('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E
M9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N
M9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@
M("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D
M;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M
M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE
M<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@
M("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@
M:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@
M("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@
M("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO
M="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@
M("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@
M("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@
M("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I
M*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@
M("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@
M("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@
M("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@
M1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER
M;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E
M=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@
M("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M
M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@
M("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@
M("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G
M:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@
M("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A
M;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X
M*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D
M8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@
M)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN
M(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@
M(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M
M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@
M(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z
M.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E
M($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M
M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@
M("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@
M("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@
M("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@
M("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@
M("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@
M("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@
M('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@
M("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)
M9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@
M*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R
M97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)
M3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*
M"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@
M(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q
M=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@
M0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R
M<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E
M($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL
M93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@
M6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z
M.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O
M;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R
M97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I
M<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER
M92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L
M('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#
M('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D
M:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP
M(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@
M("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@
M("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I
M"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE
M.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@
M979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W
M=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S
M97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE3
M5$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G
M.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U
M.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L
M("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8[
M"B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@
M("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@
M<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@
M("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I
M;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D
M9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F
M:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.
M?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!]
M(#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@
M("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS
M=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@
M;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T
M96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@
M("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@
M("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92![
M"B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I
M;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@
M;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@
M)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U
M<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@
M("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!
M4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@
M)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@
M(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?
M9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@
M=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI
M;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*
M<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92![
M"B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@
M("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG
M4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%
M35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*
M("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*
M("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L
M96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q
M(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U
M8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H
M*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L
M<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?
M:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@
M("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X
M<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]
M"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K
M86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH```!P87(N<&P``-AZ_W\!
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````+6;``"AFP````````$````!`````0```+("```!````
M`0,```$```!-!```#````$&7```-````%<$``!D```#TK@$`&P````0````:
M````^*X!`!P````$````]?[_;ZR!```%````/(T```8```"<A0``"@```/T%
M```+````$````!4``````````P````"P`0`"````D`(``!0````1````%P``
M`+"4```1````D)0``!(````@````$P````@```#^__]O,)0``/___V\#````
M\/__;SJ3````````````````````````````````````````````````````
M````````````````KP$```````````!,EP``3)<``$R7``!,EP``3)<``$R7
M``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<`
M`$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``
M3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,
MEP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7
M``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<`
M`$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``
M3)<``$R7``!,EP``3)<``$R7``!,EP``3)<``$R7``!,EP``````````````
M````_____W`@`0#I6P``03````!A96%B:0`!)@````4W+4$`!@H'00@!"0(*
M!!($%`$5`1<#&`$9`1H"&P,L`4=#0SH@*%5B=6YT=2],:6YA<F\@-"XU+C(M
M,75B=6YT=3(I(#0N-2XR```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM
M=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L
M+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YD871A
M`"YB<W,`+D%232YA='1R:6)U=&5S`"YC;VUM96YT````````````````````
M````````````````````````````````````"P````$````"````5($``%0!
M```3```````````````!`````````!,````'`````@```&B!``!H`0``(```
M````````````!``````````A````!P````(```"(@0``B`$``"0`````````
M``````0`````````-````/;__V\"````K($``*P!``#P`P``!0`````````$
M````!````#X````+`````@```)R%``"<!0``H`<```8````!````!````!``
M``!&`````P````(````\C0``/`T``/T%``````````````$`````````3@``
M`/___V\"````.I,``#H3``#T````!0`````````"`````@```%L```#^__]O
M`@```#"4```P%```8`````8````#````!`````````!J````"0````(```"0
ME```D!0``"`````%``````````0````(````<P````D````"````L)0``+`4
M``"0`@``!0````P````$````"````'P````!````!@```$"7``!`%P``"@``
M````````````!`````````!W`````0````8```!,EP``3!<```0$````````
M``````0````$````@@````$````&````4)L``%`;``#$)0`````````````(
M`````````(@````!````!@```!3!```400``!@``````````````!```````
M``".`````0````(````<P0``'$$``%Q?``````````````0`````````E@``
M``$``'""````>"`!`'B@```(````#0`````````$`````````*$````.````
M`P```/2N`0#TK@``!```````````````!`````````"M````#P````,```#X
MK@$`^*X```0```````````````0`````````N0````$````#````_*X!`/RN
M```$```````````````$`````````+X````&`````P````"O`0``KP````$`
M``8`````````!`````@```#'`````0````,`````L`$``+```%@!````````
M``````0````$````S`````$````#````6+$!`%BQ```4```````````````$
M`````````-(````(`````P```'"Q`0!LL0``-!``````````````"```````
M``#7`````P``<```````````;+$``#$```````````````$`````````YP``
M``$````P`````````)VQ```J```````````````!`````0````$````#````
M``````````#'L0``\````````````````0`````````!````3)<`````````
M``P`!````%R7```````````,``$```!@EP``````````#``'````P)<`````
M``````P``0```,27```````````,``<````@F0``````````#``!````))D`
M``````````P`!P```!2:```````````,``$````8F@``````````#``'````
MJ)H```````````P``0```*R:```````````,``<```#<F@``````````#``!
M````X)H```````````P`!P```#2;```````````,``$````XFP``````````
,#```)&$`)&0`)'0`
